==> nextcloud-20.0.10.tgz: nextcloud/apps/updatenotification/l10n/nb.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} er tilgjengelig. Få mer informasjon om å oppdatere.",
    "Channel updated" : "Kanal oppdatert",
    "Update notifications" : "Oppdateringsvarsel",
    "The update server could not be reached since %d days to check for new updates." : "Har ikke oppnådd kontakt med oppdateringsserveren på %d dager for å se etter nye oppdateringer.",
    "Please check the Nextcloud and server log files for errors." : "Se i Nextcloud- og server-loggen etter feil.",
    "Update to %1$s is available." : "Oppdatering til %1$s er tilgjengelig.",
    "Update for %1$s to version %2$s is available." : "Oppdatering for %1$s til versjon %2$s er tilgjengelig.",
    "Update for {app} to version %s is available." : "Oppdatering for {app} til versjon %s er tilgjengelig.",
    "Update notification" : "Oppdateringsvarsel",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Viser oppdateringsvarsler for Nextcloud og gir SSO for oppdatereren.",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Versjonen du kjører vedlikeholdes ikke lengre. Vennligst sørg for å oppdatere til en støttet versjon så snart som mulig.",
    "View in store" : "Vis i butikk",
    "Open updater" : "Åpne oppdaterer",
    "Download now" : "Last ned nå",
    "What's new?" : "Hva er nytt?",
    "The update check is not yet finished. Please refresh the page." : "Oppdateringssjekken er ikke ferdig, vennligst oppdater siden.",
    "Your version is up to date." : "Du har nyeste versjon.",
    "A non-default update server is in use to be checked for updates:" : "En ikke-forvalgt oppdateringsserver brukes for å se etter oppdateringer:",
    "Update channel:" : "Oppdateringskanal:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Du kan alltid oppdatere til en nyere versjon. Men du kan aldri nedgradere til en mer stabil versjon.",
    "Notify members of the following groups about available updates:" : "Informer medlemmene i følgende grupper om tilgjengelig oppdateringer:",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Den valgte oppdateringskanalen gjør dedikerte varsler til denne serveren utdatert.",
    "The selected update channel does not support updates of the server." : "Den valgte oppdateringskanalen tilbyr ikke oppdateringer av serveren.",
    "A new version is available: <strong>{newVersionString}</strong>" : "En ny versjon er tilgjengelig: <strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "Sist sjekket {lastCheckedDate}",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Forsikre deg om at <samp>appstoreenabled</samp> ikke er satt til false i config.php.",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "Kunne ikke opprette forbindelse med appstore eller den rapporterte ingen oppdateringer. Søk manuelt for oppdatering eller sørg for at din tjener har tilgang til internet og kan opprette forbindelse med appstore.",
    "View changelog" : "Se endringslogg",
    "Enterprise" : "Bedrift",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "For bedriftsbruk. Tilbyr alltid det siste oppdateringsnivået, men oppdateres ikke til neste store utgivelse umiddelbart. Denne oppdateringen skjer når Nextcloud GmbH har gjort ytterligere herding og testing for store og oppdragskritiske distribusjoner. Denne kanalen er bare tilgjengelig for kunder og tilbyr Nextcloud Enterprise-pakken.",
    "Stable" : "Stabil",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Den siste stabile versjonen. Den er egnet for vanlig bruk og vil alltid oppdatere til den siste store versjonen.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "En pre-release versjon bare for testing av nye funksjoner, ikke for produksjonsmiljøer.",
    "Apps missing updates" : "Apper mangler oppdateringer",
    "Apps with available updates" : "Apper med tilgjengelige oppdateringer",
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Vær oppmerksom på at etter en ny utgivelse kan det ta noe tid før den vises her. Vi ruller ut nye versjonen spredt utover tid til våre brukere, og av og til hoppes det over en versjon når problemer dukker opp.",
    "Only notification for app updates are available." : "Kun varsler for app-oppdateringer er tilgjengelig.",
    "Checking apps for compatible updates" : "Kontrollerer programmer for kompatible oppdateringer",
    "<strong>All</strong> apps have an update for this version available" : "<strong>Alle</strong> apper har en oppdatering tilgjengelig for denne versjonen",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong>  app har ingen oppdatering tilgjengelig for denne versjonen","<strong>%n</strong> apper har ingen oppdatering tilgjengelig for denne versjonen"]
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-21.0.0p0.tgz: nextcloud/apps/updatenotification/l10n/nb.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} er tilgjengelig. Få mer informasjon om å oppdatere.",
    "Channel updated" : "Kanal oppdatert",
    "Update notifications" : "Oppdateringsvarsel",
    "The update server could not be reached since %d days to check for new updates." : "Har ikke oppnådd kontakt med oppdateringsserveren på %d dager for å se etter nye oppdateringer.",
    "Please check the Nextcloud and server log files for errors." : "Se i Nextcloud- og server-loggen etter feil.",
    "Update to %1$s is available." : "Oppdatering til %1$s er tilgjengelig.",
    "Update for %1$s to version %2$s is available." : "Oppdatering for %1$s til versjon %2$s er tilgjengelig.",
    "Update for {app} to version %s is available." : "Oppdatering for {app} til versjon %s er tilgjengelig.",
    "Update notification" : "Oppdateringsvarsel",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Viser oppdateringsvarsler for Nextcloud og gir SSO for oppdatereren.",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Versjonen du kjører vedlikeholdes ikke lengre. Vennligst sørg for å oppdatere til en støttet versjon så snart som mulig.",
    "Apps missing updates" : "Apper mangler oppdateringer",
    "View in store" : "Vis i butikk",
    "Apps with available updates" : "Apper med tilgjengelige oppdateringer",
    "Open updater" : "Åpne oppdaterer",
    "Download now" : "Last ned nå",
    "What's new?" : "Hva er nytt?",
    "The update check is not yet finished. Please refresh the page." : "Oppdateringssjekken er ikke ferdig, vennligst oppdater siden.",
    "Your version is up to date." : "Du har nyeste versjon.",
    "A non-default update server is in use to be checked for updates:" : "En ikke-forvalgt oppdateringsserver brukes for å se etter oppdateringer:",
    "Update channel:" : "Oppdateringskanal:",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Du kan alltid oppdatere til en nyere versjon. Men du kan aldri nedgradere til en mer stabil versjon.",
    "Notify members of the following groups about available updates:" : "Informer medlemmene i følgende grupper om tilgjengelig oppdateringer:",
    "Only notification for app updates are available." : "Kun varsler for app-oppdateringer er tilgjengelig.",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Den valgte oppdateringskanalen gjør dedikerte varsler til denne serveren utdatert.",
    "The selected update channel does not support updates of the server." : "Den valgte oppdateringskanalen tilbyr ikke oppdateringer av serveren.",
    "A new version is available: <strong>{newVersionString}</strong>" : "En ny versjon er tilgjengelig: <strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "Sist sjekket {lastCheckedDate}",
    "Checking apps for compatible updates" : "Kontrollerer programmer for kompatible oppdateringer",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Forsikre deg om at <samp>appstoreenabled</samp> ikke er satt til false i config.php.",
    "Could not connect to the appstore or the appstore returned no updates at all. Search manually for updates or make sure your server has access to the internet and can connect to the appstore." : "Kunne ikke opprette forbindelse med appstore eller den rapporterte ingen oppdateringer. Søk manuelt for oppdatering eller sørg for at din tjener har tilgang til internet og kan opprette forbindelse med appstore.",
    "<strong>All</strong> apps have an update for this version available" : "<strong>Alle</strong> apper har en oppdatering tilgjengelig for denne versjonen",
    "View changelog" : "Se endringslogg",
    "Enterprise" : "Bedrift",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "For bedriftsbruk. Tilbyr alltid det siste oppdateringsnivået, men oppdateres ikke til neste store utgivelse umiddelbart. Denne oppdateringen skjer når Nextcloud GmbH har gjort ytterligere herding og testing for store og oppdragskritiske distribusjoner. Denne kanalen er bare tilgjengelig for kunder og tilbyr Nextcloud Enterprise-pakken.",
    "Stable" : "Stabil",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "Den siste stabile versjonen. Den er egnet for vanlig bruk og vil alltid oppdatere til den siste store versjonen.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "En pre-release versjon bare for testing av nye funksjoner, ikke for produksjonsmiljøer.",
    "_<strong>%n</strong> app has no update for this version available_::_<strong>%n</strong> apps have no update for this version available_" : ["<strong>%n</strong>  app har ingen oppdatering tilgjengelig for denne versjonen","<strong>%n</strong> apper har ingen oppdatering tilgjengelig for denne versjonen"],
    "Note that after a new release it can take some time before it shows up here. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found." : "Vær oppmerksom på at etter en ny utgivelse kan det ta noe tid før den vises her. Vi ruller ut nye versjonen spredt utover tid til våre brukere, og av og til hoppes det over en versjon når problemer dukker opp."
},
"nplurals=2; plural=(n != 1);");
